.. clicast documentation master file, created by
   sphinx-quickstart on Thu Dec 25 23:46:56 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to clicast's documentation!
===================================

.. toctree::
   :maxdepth: 2

   README


API Documentation
=================

.. toctree::
   :maxdepth: 2

   api/clicast
   api/cast

Change Log
=================

.. toctree::
   :maxdepth: 1

   CHANGELOG

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

